@@ -96,38 +96,38 @@ read.Tilia <- function(fName) {
   return(out)
 }
 
-read.C2Model <- function(fName) {
-    if (requireNamespace("RODBC", quietly=TRUE)==FALSE) {
-       stop("This function requires package RODBC")
-    }
-    channel <- RODBC::odbcConnectExcel(fName)
-    tabs <- RODBC::sqlTables(channel, errors=TRUE)
-    tabs <- tabs[tabs$TABLE_TYPE == "TABLE", ]
-    ntabs <- nrow(tabs)
-    X <- vector("list", length=ntabs)
-    names(X) <- tabs$TABLE_NAME
-    for (i in 1:ntabs) {
-       X1 <- RODBC::sqlFetch(channel, tabs$TABLE_NAME[i], colnames=FALSE, rownames=FALSE)
-       if (tabs$TABLE_NAME[i] == "Summary") {
-          X[[i]] <- as.character(X1[!is.na(X1), 1])
-       } else {
-          rownames(X1) <- X1[, 2]
-          X[[i]] <- X1[, -c(1:3)]
-       }
-    }
-    RODBC::odbcCloseAll()
-    class(X) <- "C2"
-    X
-}
+#read.C2Model <- function(fName) {
+#    if (requireNamespace("RODBC", quietly=TRUE)==FALSE) {
+#       stop("This function requires package RODBC")
+#    }
+#    channel <- RODBC::odbcConnectExcel(fName)
+#    tabs <- RODBC::sqlTables(channel, errors=TRUE)
+#    tabs <- tabs[tabs$TABLE_TYPE == "TABLE", ]
+#    ntabs <- nrow(tabs)
+#    X <- vector("list", length=ntabs)
+#    names(X) <- tabs$TABLE_NAME
+#    for (i in 1:ntabs) {
+#       X1 <- RODBC::sqlFetch(channel, tabs$TABLE_NAME[i], colnames=FALSE, rownames=FALSE)
+#       if (tabs$TABLE_NAME[i] == "Summary") {
+#          X[[i]] <- as.character(X1[!is.na(X1), 1])
+#       } else {
+#          rownames(X1) <- X1[, 2]
+#          X[[i]] <- X1[, -c(1:3)]
+#       }
+#    }
+#    RODBC::odbcCloseAll()
+#    class(X) <- "C2"
+#    X
+#}
 
-print.C2 <- function(x, ...) {
-   n <- grep(":", x$Summary)
-   cat(x$Summary[n], sep="\n")
-   cat("\nModel contains the following components:\n\n")
-   cat(names(x), sep="\n")
-}
+#print.C2 <- function(x, ...) {
+#   n <- grep(":", x$Summary)
+#   cat(x$Summary[n], sep="\n")
+#   cat("\nModel contains the following components:\n\n")
+#   cat(names(x), sep="\n")
+#}
 
-summary.C2 <- function(x, ...) {
-   cat(as.character(x$Summary), sep="\n")
-}
+#summary.C2 <- function(x, ...) {
+#   cat(as.character(x$Summary), sep="\n")
+#}
 
